| .get_delay_matrix_from_delay_distributions | R Documentation |
Build delay distribution matrix from a single delay or a list of delay distributions
.get_delay_matrix_from_delay_distributions(distributions, N = 1, ...)
distributions |
single distribution or list of distributions, each element is either a distribution list or discretized probability distribution vector. |
N |
integer. Dimension of output matrix. Ignored if a list of distributions is provided. |
... |
Arguments passed on to
|
delay distribution matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.