dot-is_value_in_accepted_values_vector: Utility functions for input validity.

.is_value_in_accepted_values_vectorR Documentation

Utility functions for input validity.

Description

Utility function that checks if a specific user given parameter value is among the accepted ones, in which case it returns TRUE Throws an error otherwise.

Usage

.is_value_in_accepted_values_vector(string_user_input, parameter_name)

Arguments

string_user_input

A string containing the value that the user passed for the tested string type parameter.

parameter_name

A string containing the name the tested parameter had in the initial function in which it was passed.

Value

TRUE if all tests were passed. Throws an error otherwise.


covid-19-Re/estimateR documentation built on Sept. 14, 2024, 5:49 a.m.