| inner_module | R Documentation |
Inner module option characteristics
incidence_input, input, output, input_a, input_b |
Module input object. List with two elements:
|
Module input object. List with two elements:
A numeric vector named values: the incidence recorded on consecutive time steps.
An integer named index_offset: the offset, counted in number of time steps,
by which the first value in values is shifted compared to a reference time step
This parameter allows one to keep track of the date of the first value in values
without needing to carry a date column around.
A positive offset means values are delayed in the future compared to the reference values.
A negative offset means the opposite.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.