| EpiEstim_wrapper | R Documentation |
EpiEstim wrappers arguments
minimum_cumul_incidence |
Numeric value.
Minimum number of cumulated infections before starting the Re estimation.
Default is |
mean_serial_interval |
Numeric positive value. |
std_serial_interval |
Numeric positive value. |
mean_Re_prior |
Numeric positive value. |
output_HPD |
Boolean. If TRUE, return the highest posterior density interval with the output. |
import_incidence_input |
NULL or module input object. List with two elements:
If not NULL, this data represents recorded imported cases.
And then |
If output_HPD = FALSE,
value is a module object (a list of the same kind as incidence_input).
The values element of the list then contains the Re estimates.
If output_HPD = TRUE, a list of three module objects is returned.
Re_estimate contains the Re estimates.
Re_highHPD and Re_lowHPD contain
the higher and lower boundaries of the HPD interval,
as computed by estimate_R
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.