| .is_value_in_accepted_values_vector | R Documentation |
Utility function that checks if a specific user given parameter value is among the accepted ones, in which case it returns TRUE Throws an error otherwise.
.is_value_in_accepted_values_vector(string_user_input, parameter_name)
string_user_input |
A string containing the value that the user passed for the tested string type parameter. |
parameter_name |
A string containing the name the tested parameter had in the initial function in which it was passed. |
TRUE if all tests were passed. Throws an error otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.